package template

import util.CodeUtil.toFileName

object CodeTemplate {
    fun getPageRouter(stateful: Boolean, pageName: String, routerPath: String?, viewModelLocation: String): String {
        val routerAnnotation = if (routerPath != null) "\n@RouterPage(path: \"${routerPath}\")" else ""
        val routerAnnotationImport = if (routerPath != null) "\nimport 'package:router_gen/router_gen.dart';\n" else ""
        if (stateful) {
            return  """import 'package:flutter/material.dart';$routerAnnotationImport
import 'package:school_parent/core/provider/exports.dart';
import 'package:school_parent/apps/learning_park/common/common_app_bar.dart';
import 'package:school_parent/view_model${viewModelLocation}/${toFileName(pageName)}_view_model.dart';
$routerAnnotation
class ${pageName}Page extends StatefulWidget {
  @override
  _${pageName}PageState createState() => _${pageName}PageState();
}

class _${pageName}PageState extends State<${pageName}Page>
    with StatePageHelper<${pageName}Page, ${pageName}ViewModel> {
  @override
  Widget buildAppBar(${pageName}ViewModel model) => CommonAppBar(
    title: '${pageName}',
  );
  
  @override
  Widget buildWidget(BuildContext context, ${pageName}ViewModel model) {
    return Container();
  }
 
  @override
  void initState() {
    super.initState();
  }
 
  @override
  void dispose() { 
    super.dispose();
  }
}"""
        } else {
            return """import 'package:flutter/material.dart';$routerAnnotationImport
import 'package:school_parent/core/provider/exports.dart';
import 'package:school_parent/view_model${viewModelLocation}/${toFileName(pageName)}_view_model.dart';
$routerAnnotation
class ${pageName}Page extends StatelessWidget
    with StatelessPageHelper<${pageName}ViewModel> {
  @override
  Widget buildWidget(BuildContext context, ${pageName}ViewModel model) {
    return Container();
  }
}
"""
        }
    }

    fun getViewModel(pageName: String, ): String{
        return """import 'package:injectable/injectable.dart';
import 'package:school_parent/core/provider/exports.dart';

@injectable
class ${pageName}ViewModel extends BaseFutureViewModel<void> {
  ${pageName}ViewModel();

  @override
  Future<void> futureToRun() {
    return null;
  }
}""";
    }
}