package ui

import com.intellij.openapi.project.Project
import com.intellij.openapi.ui.DialogWrapper
import java.awt.FlowLayout
import java.awt.GridLayout
import javax.swing.*

interface ConfirmAction {
    fun onConFirm(pageName: String, stateful: Boolean, router: Boolean)
}

class PageCreateDialog(project: Project, private val onConfirm: ConfirmAction) : DialogWrapper(project) {
    private val textField = JTextField()
    private val stateGroup = ButtonGroup()
    private val checkbox = JCheckBox("生成路由注解")

    init {
        // dialog config
        title = "i2 Page Creation"
        setOKButtonText("确定")
        setCancelButtonText("取消")
        setResizable(true)
        init()
    }

    override fun createCenterPanel(): JComponent? = createCenter()

    override fun getPreferredFocusedComponent(): JComponent? {
        return textField
    }

    override fun doOKAction() {
        super.doOKAction()
        onConfirm.onConFirm(
            textField.text.trim(),
            stateGroup.selection.actionCommand == "Stateful",
            checkbox.isSelected
        )
    }

    private fun createCenter() : JPanel {
        val panel  = JPanel()
        panel.layout = GridLayout(4, 1)
        // page name hint
        val hintLabel = JLabel("页面名（如MyHomePage只需输入MyHome）")
        panel.add(hintLabel)

        // page name text field
        panel.add(textField)

        // choose stateful or stateless
        val statePanel = JPanel()
        statePanel.layout = FlowLayout(FlowLayout.LEFT)
        val hintPageLabel = JLabel("页面类型")
        statePanel.add(hintPageLabel)
        val statefulRadioBtn = JRadioButton("Stateful", true)
        statefulRadioBtn.actionCommand = "Stateful"
        statePanel.add(statefulRadioBtn)

        val statelessRadioBtn = JRadioButton("Stateless")
        statelessRadioBtn.actionCommand = "Stateless"
        statePanel.add(statelessRadioBtn)

        stateGroup.add(statefulRadioBtn)
        stateGroup.add(statelessRadioBtn)
        panel.add(statePanel)

        // choose generate router
        panel.add(checkbox)

        return panel
    }
}