package util

import com.intellij.openapi.command.WriteCommandAction
import com.intellij.openapi.project.Project
import com.intellij.openapi.vfs.VfsUtil
import com.intellij.openapi.vfs.VirtualFile
import com.intellij.psi.PsiDirectory
import com.intellij.psi.PsiElement
import com.intellij.psi.impl.file.PsiDirectoryFactory
import com.intellij.psi.search.FilenameIndex
import com.intellij.psi.search.GlobalSearchScope
import constant.Constants

object FlutterUtil {
    fun isValidAction(project: Project, psiElement: PsiElement?, rootPath: String): Boolean {
        // 检查是否为Flutter应用
        var exist = false
        for (pubspec in FilenameIndex.getFilesByName(
            project,
            Constants.flutterTarget,
            GlobalSearchScope.projectScope(project)
        )) {
            if (pubspec.isValid) {
                exist = true
                break
            }
        }
        // 检查是否在文件夹下操作及是否在lib子目录下执行
        var inLib = false
        if (psiElement != null && psiElement is PsiDirectory) {
            if (psiElement.virtualFile.path.startsWith("${rootPath}/lib")) {
                inLib = true
            }
        }

        return exist && project.name == Constants.projectName && inLib
    }

    fun writePage(project: Project, dir: String, fileName: String, content: String) {
        WriteCommandAction.runWriteCommandAction(project) {
            var dirVirtualFile: VirtualFile? = null
            dirVirtualFile = VfsUtil.createDirectoryIfMissing(dir)
            val dirPsiDirectory = PsiDirectoryFactory.getInstance(project).createDirectory(dirVirtualFile!!)
            val filePsiFile = dirPsiDirectory.createFile(fileName)
            filePsiFile.virtualFile.setBinaryContent(content.toByteArray())
//            CodeUtil.reformatDartCode(filePsiFile)
            filePsiFile.navigate(true)
        }
    }
}